searchData={"items":[{"type":"task","title":"mix nbpm.get_port_number","doc":"Get port number.\n\nWithout arguments\n`mix nbpm.get_port_number`\nprints current project application port.\n\nWith one argument\n`mix nbpm.get_port_number my_app`\nprints port number for that argument.","ref":"Mix.Tasks.Nbpm.GetPortNumber.html"},{"type":"task","title":"mix nbpm.install","doc":"Installs `Nbpm` into `Mix.Release` scripts.","ref":"Mix.Tasks.Nbpm.Install.html"},{"type":"module","title":"Nbpm","doc":"Main module for Name-Based Port Mapper (Nbpm).\n\nThis module provides the core functionality for mapping node names to port\nnumbers in the context of Erlang distribution. It is designed to be used as\na custom EPMD (Erlang Port Mapper Daemon) module, which you can specify\nwith the `-epmd_module` option.","ref":"Nbpm.html"},{"type":"module","title":"Node name to port number mapping variants - Nbpm","doc":"- **Last up to 5 digits:** If the node name ends with digits, the last up to\n5 digits from the node name are considered as the port number. For example,\nfor a node name \"my_node12345\" the port number would be 12345.\n\n- **Special Prefixes:** If a node name starts with \"rem-\" or \"rpc-\", it\nindicates that the OS should assign a random port. This is for\ncompatibility with `Mix.Release`.\n\n- **Hash-Based Port:** If none of the previous options match, the node name\nis hashed using the `:erlang.phash2` function, and the resulting hash is\nused as the port number. The port range is from 1024 to 65535.\n`:erlang.phash2` is a portable hash function that gives the same hash for\nthe same Erlang term regardless of machine architecture and ERTS version,\nthia ensures consistent name-to-port mappings across different machine\narchitectures and ERTS versions.\n\nTo determine to which port your node name translates, you can use the\n`mix nbpm.get_port_number` (`Mix.Tasks.Nbpm.GetPortNumber`) task helper.","ref":"Nbpm.html#module-node-name-to-port-number-mapping-variants"},{"type":"module","title":"Compatibility - Nbpm","doc":"Nbpm is compatible with Mix releases.\n\nWhen you execute `\"_build/prod/rel/your_app/bin/your_app remote\"`,\n`Mix.Release` script automatically generates node names\nin the format \"rem-$(rand)-name\" or \"rem-$(rand)-sname\".\n\nSimilarly, when you execute `\"_build/prod/rel/your_app/bin/your_app rpc\"`,\n`Mix.Release` script generates node names\nas \"rpc-$(rand)-name\" or \"rpc-$(rand)-sname\".\n\nNbpm responds to these names by offering port number 0, indicating that the\nOS should assign a random port.","ref":"Nbpm.html#module-compatibility"},{"type":"module","title":"References - Nbpm","doc":"* [How to Implement an Alternative Node Discovery for Erlang Distribution](https://www.erlang.org/doc/apps/erts/alt_disco)\n* `Mix.Release`","ref":"Nbpm.html#module-references"},{"type":"function","title":"Nbpm.address_please/3","doc":"","ref":"Nbpm.html#address_please/3"},{"type":"function","title":"Nbpm.available_ports_count/0","doc":"","ref":"Nbpm.html#available_ports_count/0"},{"type":"function","title":"Nbpm.listen_port_please/2","doc":"","ref":"Nbpm.html#listen_port_please/2"},{"type":"function","title":"Nbpm.name_to_port/1","doc":"Translates node name to port number.","ref":"Nbpm.html#name_to_port/1"},{"type":"function","title":"Nbpm.names/1","doc":"","ref":"Nbpm.html#names/1"},{"type":"function","title":"Nbpm.port_please/2","doc":"","ref":"Nbpm.html#port_please/2"},{"type":"function","title":"Nbpm.port_please/3","doc":"","ref":"Nbpm.html#port_please/3"},{"type":"function","title":"Nbpm.register_node/2","doc":"","ref":"Nbpm.html#register_node/2"},{"type":"function","title":"Nbpm.register_node/3","doc":"","ref":"Nbpm.html#register_node/3"},{"type":"function","title":"Nbpm.start_link/0","doc":"","ref":"Nbpm.html#start_link/0"},{"type":"extras","title":"Nbpm","doc":"# Nbpm\n\nName-Based Port Mapper\n\n---\n\n[![CI](https://github.com/pertsevds/nbpm/actions/workflows/ci.yml/badge.svg)](https://github.com/pertsevds/nbpm/actions/workflows/ci.yml)\n[![Coverage Status](https://coveralls.io/repos/github/pertsevds/nbpm/badge.svg?branch=main)](https://coveralls.io/github/pertsevds/nbpm?branch=main)\n[![Hex.pm License](https://img.shields.io/hexpm/l/nbpm)](https://hex.pm/packages/nbpm)\n[![Hex.pm Version](https://img.shields.io/hexpm/v/nbpm)](https://hex.pm/packages/nbpm)\n[![Hex.pm Docs](https://img.shields.io/badge/hex-docs-lightgreen)](https://hexdocs.pm/nbpm)\n[![Hex.pm Downloads](https://img.shields.io/hexpm/dt/nbpm)](https://hex.pm/packages/nbpm)\n\nWith Nbpm you don't need EPMD daemon.\nNo additional daemons, no additional configs.\nEasy and simple distribution without EPMD.","ref":"readme.html"},{"type":"extras","title":"Features - Nbpm","doc":"- `Mix.Release` compatibility.\n- Ability to specify port number in the node name.\n- Hash-Based Port from node name.\n- [Mix task to get port number from node name](#mix-task-to-get-port-number-from-node-name).","ref":"readme.html#features"},{"type":"extras","title":"Installation - Nbpm","doc":"To use `Nbpm` in your Elixir project, add it as a dependency\nin your `mix.exs` file:\n\n```elixir\ndef deps do\n[\n    {:nbpm, \"~> 0.3.1\"}\n]\nend\n```\n\nRun\n\n```shell\nmix deps.get\n```\n\nto download it.\n\nThen run\n\n```shell\nmix nbpm.install\n```\n\nto install Nbpm into your project.\n\n> [!NOTE]\n> `mix nbpm.install` will add `-start_epmd false -epmd_module Elixir.Nbpm` to\n> `ELIXIR_ERL_OPTIONS` in files `rel/env.sh.eex` and `rel/env.bat.eex`.\n>\n> This will disable loading of EPMD daemon\n> and will use Nbpm module to map node names to ports.","ref":"readme.html#installation"},{"type":"extras","title":"Mix task to get port number from node name - Nbpm","doc":"You can get port number for your current app name\nby using `nbpm.get_port_number` task:\n\n```shell\nmix nbpm.get_port_number\n```\n\n`mix nbpm.get_port_number` will output port number for your current app.\n\nOr you can supply any node name as an argument:\n\n```shell\nmix nbpm.get_port_number my_app\n```\n\n`mix nbpm.get_port_number my_app` will output port number\nfor `my_app` node name.","ref":"readme.html#mix-task-to-get-port-number-from-node-name"},{"type":"extras","title":"Todo - Nbpm","doc":"Installation to global:","ref":"readme.html#todo"},{"type":"extras","title":"Documentation - Nbpm","doc":"","ref":"readme.html#documentation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}